import { ContentArea } from '@c/ui/ContentArea';
import { useQuery, } from '@tanstack/react-query';
import { Button, Col, Divider, Row, message } from 'antd';
import React, {FC, useCallback, useRef, useState} from 'react';
import 'twin.macro';
import Logo from 'assets/logo.png'
import { reportTenementDetail } from '@q/publicity';
import { isCorrectResult } from '@u/asyncs';
import Card from './components/Card';
import Unit from './components/Unit';
import { outputWithPrecision } from '@u/funcs';
import html2pdf from "html2pdf.js";
import dayjs from "dayjs";
import TopTitle from './components/TopTitle';
import TopContent from './components/TopContent';
// 核心代码
import { useSearchParams } from 'react-router-dom'
import {getRoundNumber} from "@/utils";
import 'twin.macro';
import {Meter04KvType} from "@/shared/model-park";

function getNestAmount(arr: string[] = []): string {
    if (!arr.length) {
        return "0"
    }
    return arr?.reduce((prev, next) => {
        return getRoundNumber(Number(prev || 0) + Number(next || 0))
    })
}

export const UserReport: FC = () => {
    const [searchParams] = useSearchParams()
    const tid = searchParams.get("tenement");
    const rid = searchParams.get("report");
    const amount = useRef<string>();
    const { data } = useQuery(
        ['report-tenement-detail', rid, tid],
        () => reportTenementDetail(rid, tid),
        {
            select: res => {
                if (isCorrectResult(res)) {
                    amount.current = res.amount;
                    return res.detail
                }
                message.error(res.message || '获取商户电费详情失败');
                return null;
            }
        }
    );

    const [downloadLoading, setDownloadLoading] = useState(false);

    const printRef = useRef()

    const handlePrint = async () => {
        const opt = {
            margin: 0,
            filename: `${data?.comprehensive?.startDate ? dayjs(data?.comprehensive?.startDate).format("YYYY年MM月") : null}${data?.tenement?.fullName || '报表'}.pdf`,
            image: { type: "jpeg", quality: 0.98, },
            enableLinks: true,
            html2canvas: { scale: 3, useCORS: true, allowTaint: false,  },
            jsPDF: {
                unit: 'pt', // pt、mm、cm、in
                format: 'a4',
                orientation: 'p' // 纵向p，横向l

            },
        };
        setDownloadLoading(true)
        // eslint-disable-next-line @typescript-eslint/no-unsafe-call
        await html2pdf(printRef.current, opt);
        setDownloadLoading(false);
    };


    const renderTable = useCallback(() => {
        return data?.meters?.map((item, index) => {
            // const finalAmount = Number(item?.overall?.amount || 0) + Number(item?.loss?.amount || 0) + Number(item?.publicAmount || 0)
            return (
                <tr key={index}>
                    <td>{item?.address}</td>
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{outputWithPrecision(item?.startNumber, 2, '-')}</td> :
                            <td>
                                <div> 尖：{item?.startSharp} </div>
                                <div> 峰：{item?.startPeak} </div>
                                <div> 平：{item?.startFlat} </div>
                                <div> 谷：{item?.startValley} </div>
                            </td>
                    }
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{outputWithPrecision(item?.endNumber, 2, '-')}</td> :
                            <td>
                                <div> 尖：{item?.endSharp} </div>
                                <div> 峰：{item?.endPeak} </div>
                                <div> 平：{item?.endFlat} </div>
                                <div> 谷：{item?.endValley} </div>
                            </td>
                    }

                    <td>{outputWithPrecision(item?.ratio, 2, '-')}</td>
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{item?.refundAmount}</td> :
                            <td>
                                <div> 尖：{item?.refundSharp} </div>
                                <div> 峰：{item?.refundPeak} </div>
                                <div> 平：{item?.refundFlat} </div>
                                <div> 谷：{item?.refundValley} </div>
                            </td>
                    }
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{item?.nestOverall}</td> :
                            <td>
                                <div> 尖：{item?.nestSharp} </div>
                                <div> 峰：{item?.nestPeak} </div>
                                <div> 平：{item?.nestFlat} </div>
                                <div> 谷：{item?.nestValley} </div>
                            </td>
                    }
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{outputWithPrecision(item?.overall?.amount, 2, '-')}</td> :
                            <td>
                                <div> 尖：{item?.critical?.amount} </div>
                                <div> 峰：{item?.peak?.amount} </div>
                                <div> 平：{item?.flat?.amount} </div>
                                <div> 谷：{item?.valley?.amount} </div>
                            </td>
                    }

                    {/* <td>{outputWithPrecision(item?.finalTotal ? (1 / (1 - Number(item?.loss?.amount) / Number(item?.finalTotal)) - 1) * 100 : undefined, 2, '-')} %</td> */}
                    {
                        data?.tenement?.feeType === 3 ? null : (
                            data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                                <td>{outputWithPrecision(item?.loss?.amount, 2, '-')}</td> :
                                <td>
                                    <div> 尖：{item?.lossSharp} </div>
                                    <div> 峰：{item?.lossPeak} </div>
                                    <div> 平：{item?.lossFlat} </div>
                                    <div> 谷：{item?.lossValley} </div>
                                </td>

                        )
                    }
                    {
                        data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                            <td>{outputWithPrecision(item?.publicAmount, 2, '-')}</td> :
                            <td>
                                <div> 尖：{item?.poolSharp || 0} </div>
                                <div> 峰：{item?.poolPeak || 0} </div>
                                <div> 平：{item?.poolFlat || 0} </div>
                                <div> 谷：{item?.poolValley || 0} </div>
                            </td>
                    }


                    <td>{outputWithPrecision(item?.finalAmount, 2, '-')}</td>
                </tr>
            )
        })
    }, [data?.meters, data?.park?.meter04kvType])

    const renderTableSum = useCallback(() => {
        if (data?.meters?.length < 2) {
            return null;
        }
        return <tr key={data?.meters?.length + 1}>
            <td> 总计 </td>
            <td> - </td>
            <td> - </td>
            <td> - </td>
            {
                data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                    <td>{data?.comprehensive?.refundOverall}</td> :
                    <td>
                        <div> 尖：{data?.comprehensive?.refundSharp} </div>
                        <div> 峰：{data?.comprehensive?.refundPeak} </div>
                        <div> 平：{data?.comprehensive?.refundFlat} </div>
                        <div> 谷：{data?.comprehensive?.refundValley} </div>
                    </td>
            }
            {
                data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                    <td>{getNestAmount(data?.meters?.map(item => item?.nestOverall))}</td> :
                    <td>
                        <div> 尖：{getNestAmount(data?.meters?.map(item => item?.nestSharp))} </div>
                        <div> 峰：{getNestAmount(data?.meters?.map(item => item?.nestPeak))} </div>
                        <div> 平：{getNestAmount(data?.meters?.map(item => item?.nestFlat))} </div>
                        <div> 谷：{getNestAmount(data?.meters?.map(item => item?.nestValley))} </div>
                    </td>
            }
            {
                data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                    <td>{outputWithPrecision(data?.comprehensive?.consumption, 2, '-')}</td> :
                    <td>
                        <div> 尖：{data?.comprehensive?.sharpAmount} </div>
                        <div> 峰：{data?.comprehensive?.peakAmount} </div>
                        <div> 平：{data?.comprehensive?.flatAmount} </div>
                        <div> 谷：{data?.comprehensive?.valleyAmount} </div>
                    </td>
            }

            {/* <td>{outputWithPrecision(item?.finalTotal ? (1 / (1 - Number(item?.loss?.amount) / Number(item?.finalTotal)) - 1) * 100 : undefined, 2, '-')} %</td> */}
            {
                data?.tenement?.feeType === 3 ? null : (
                    data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                        <td>{outputWithPrecision(data?.comprehensive?.lossAmount, 2, '-')}</td> :
                        <td>
                            <div> 尖：{data?.comprehensive?.lossSharp} </div>
                            <div> 峰：{data?.comprehensive?.lossPeak} </div>
                            <div> 平：{data?.comprehensive?.lossFlat} </div>
                            <div> 谷：{data?.comprehensive?.lossValley} </div>
                        </td>

                )
            }
            {
                data?.park?.meter04kvType === Meter04KvType.DisableValley ?
                    <td>{outputWithPrecision(data?.comprehensive?.publicAmount, 2, '-')}</td> :
                    <td>
                        <div> 尖：{data?.comprehensive?.poolSharp || 0} </div>
                        <div> 峰：{data?.comprehensive?.poolPeak || 0} </div>
                        <div> 平：{data?.comprehensive?.poolFlat || 0} </div>
                        <div> 谷：{data?.comprehensive?.poolValley || 0} </div>
                    </td>
            }


            <td>{outputWithPrecision(
                `${(data?.park?.meter04kvType === 0 ? amount?.current : data?.comprehensive?.finalAmount) || 0}`, 2, '-')}</td>
        </tr>
    }, [data?.meters, data?.park?.meter04kvType, data?.comprehensive])

  return (
      <>
          <style>
              {
                  `
                        td {
                            padding: 0.2cm
                        }
                        ${
                      data?.park?.meter04kvType === Meter04KvType.DisableValley ? ` tr td:nth-child(1) {
                     
                                 width: 4.5cm;
                            }` : ` tr td:nth-child(1) {
                                width: 2cm;
       
                            }`
                  }
                       
                         tr td:nth-child(2), tr td:nth-child(3), tr td:nth-child(4) {
                            width: 1.5cm;
                        }
                        tr td:nth-child(5), tr td:nth-child(6), tr td:nth-child(7), tr td:nth-child(8), tr td:nth-child(9), tr td:nth-child(10) {
                            width: 2cm;
                        }
                        #content, .ant-col {
                            font-size: 0.34cm;
                        }
                    `
              }
          </style>
          <div style={{
              position: 'fixed',
              width: '100%',
              height: '100%',
              left: 0,
              right: 0,
              top: 0,
              bottom: 0,
              margin: 'auto',
              zIndex: 99,
              background: '#fff',
              display: 'flex',
              justifyContent: 'center',
              alignItems: "center"
          }}>

              <Button loading={downloadLoading} type='primary' tw='' onClick={() => handlePrint()}> 下载 </Button>


          </div>
          <div ref={printRef}>
              <ContentArea>
                  <div id="content">
                      <div>
                          <img src={Logo} alt="" width={60} height={60}/>
                      </div>
                      <div tw='mt-4' style={{fontSize: "18px", fontWeight: 600}}>
                          尊敬的{data?.tenement?.fullName}，这是贵公司 &nbsp;
                          {dayjs(data?.comprehensive?.startDate).format("MM")} 月的电费账单
                      </div>
                      <div tw='flex mt-6 flex-row' style={{backgroundColor: "#f0f0f0", padding: '18px 20px'}}>
                          <div tw='flex flex-1 flex-col'>
                              <Row gutter={16}>
                                  <Col span={5} style={{display: "flex", flexDirection: "column"}}>
                                      <div>账单周期</div>
                                      <div style={{
                                          fontSize: "20px",
                                          fontWeight: 600,
                                          flex: 1,
                                          display: "flex",
                                          alignItems: "center"
                                      }}>
                                          {data?.comprehensive?.startDate ? dayjs(data?.comprehensive?.startDate).format("YYYY年MM月") : null}
                                      </div>
                                      {/* <div> {data?.comprehensive?.startDate} - {data?.comprehensive?.endDate} </div> */}
                                  </Col>
                                  <Col span={19}>
                                      <Row gutter={16}>
                                          <Col span={6}> <TopTitle> 商户编号 </TopTitle>
                                              <TopContent> {data?.tenement?.id} </TopContent> </Col>
                                          <Col span={6}>
                                              <TopTitle>商户名称</TopTitle><TopContent>{data?.tenement?.fullName}</TopContent>
                                          </Col>
                                          <Col span={6}> <TopTitle>用户类型</TopTitle><TopContent>工商业</TopContent>
                                          </Col>
                                          <Col span={6}> <TopTitle>电压等级</TopTitle><TopContent>0.4kv</TopContent>
                                          </Col>
                                      </Row>
                                      <Divider dashed tw='mt-2 mb-2 flex flex-col w-full'/>
                                      <Row gutter={16}>
                                          <div tw='mt-3 flex-1 flex flex-row'>
                                              <Col span={6}> <TopTitle>所属园区</TopTitle>
                                                  <TopContent> {data?.park?.name} </TopContent> </Col>
                                              <Col span={6}> <TopTitle>用户地址</TopTitle>
                                                  <TopContent> {data?.tenement?.address} </TopContent> </Col>
                                              <Col span={6}>
                                                  <TopTitle>抄表日期</TopTitle><TopContent>{data?.comprehensive?.endDate}</TopContent>
                                              </Col>
                                              <Col span={6}>
                                                  <TopTitle>购电方式</TopTitle><TopContent>市场化零售客户</TopContent>
                                              </Col>
                                          </div>
                                      </Row>
                                  </Col>
                              </Row>
                          </div>
                      </div>
                      <div>
                          <div tw='mt-6'>
                              账单信息
                              <Divider tw='mt-2 mb-2 flex flex-col w-full'/>
                          </div>
                          <div tw='mt-2'>
                              <div tw='flex flex-row'>
                                  <Card>
                                      <h4 tw='mt-1 mb-1'> 合计电量： </h4>
                                      <div> {
                                          outputWithPrecision(
                                              `${Number((data?.park?.meter04kvType === 0 ? amount?.current : data?.comprehensive?.finalAmount) || 0)}`, 2, '-')} &nbsp;&nbsp;千瓦时
                                      </div>
                                  </Card>
                                  <Card style={{marginLeft: 20}}>
                                      <h4 tw='mt-1 mb-1'> 合计电费： </h4>
                                      <div> {outputWithPrecision(data?.comprehensive?.total, 2, '-')} 元 &nbsp;&nbsp;</div>
                                  </Card>
                              </div>
                              <div tw='mt-3'>
                                  电费构成
                                  <Divider tw='mt-2 mb-4 flex flex-col w-full'/>
                              </div>
                              {
                                  data?.park?.meter04kvType === 0 ? (
                                      <div tw='flex flex-row items-center' style={{
                                          height: 'fit-content',
                                          alignItems: "stretch",
                                          flexGrow: "stratch"
                                      }}>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Unit> （ </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度电量： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.consumption, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {
                                                  data?.tenement?.feeType === 3 ? null : (
                                                      <>
                                                          <Unit> + </Unit>
                                                          <Card>
                                                              <h4 tw='mt-1 mb-1'> 线损电量： </h4>
                                                              <div> {outputWithPrecision(data?.comprehensive?.lossAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                                          </Card>
                                                      </>
                                                  )
                                              }

                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 公摊电量： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.publicAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {/*<Unit> - </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 退补电量： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.publicAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>*/}
                                              {/*</Card>*/}
                                              <Unit> ） </Unit><Unit> * </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度单价： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.price, 6, '-')} &nbsp;&nbsp;千瓦时/元</div>
                                              </Card>
                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 基本电费： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.basicPooled, 2, '-')} 元</div>
                                              </Card>
                                              {/*<Unit> + </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 调整电费： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.adjustPooled, 2, '-')} 元</div>*/}
                                              {/*</Card>*/}
                                          </div>
                                          <div tw='flex flex-row items-center' style={{height: '100%', flex: 1}}>
                                              <Unit> = </Unit>
                                              <Card style={{height: 200}}>
                                                  <h4 tw='mt-1 mb-1'> 本期总电费： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.total, 2, '-')} 元</div>
                                              </Card>
                                          </div>
                                      </div>
                                  ) : (
                                      <div tw='' style={{
                                          height: 'fit-content',
                                          alignItems: "stretch",
                                          flexGrow: "stratch"
                                      }}>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Unit> （ </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度电量（尖）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.sharpAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {
                                                  data?.tenement?.feeType === 3 ? null : (
                                                      <>
                                                          <Unit> + </Unit>
                                                          <Card>
                                                              <h4 tw='mt-1 mb-1'> 线损电量（尖）： </h4>
                                                              <div> {outputWithPrecision(data?.comprehensive?.lossSharp, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                                          </Card>
                                                      </>
                                                  )
                                              }

                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 公摊电量（尖）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.poolSharp || '0', 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {/*<Unit> - </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 退补电量（尖）： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.refundSharp, 2, '-')} &nbsp;&nbsp;千瓦时</div>*/}
                                              {/*</Card>*/}
                                              <Unit> ） </Unit><Unit> * </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度单价（尖）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.priceSharp, 6, '-')} &nbsp;&nbsp;千瓦时/元</div>
                                              </Card>
                                              <Unit> = </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（尖）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalSharpFee, 2, '-')} 元&nbsp;&nbsp;</div>
                                              </Card>
                                          </div>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Unit> （ </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度电量（峰）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.peakAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {
                                                  data?.tenement?.feeType === 3 ? null : (
                                                      <>
                                                          <Unit> + </Unit>
                                                          <Card>
                                                              <h4 tw='mt-1 mb-1'> 线损电量（峰）： </h4>
                                                              <div> {outputWithPrecision(data?.comprehensive?.lossPeak, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                                          </Card>
                                                      </>
                                                  )
                                              }

                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 公摊电量（峰）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.poolPeak, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {/*<Unit> - </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 退补电量（峰）： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.refundPeak, 2, '-')} &nbsp;&nbsp;千瓦时</div>*/}
                                              {/*</Card>*/}
                                              <Unit> ） </Unit><Unit> * </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 用电单价（峰）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.pricePeak, 6, '-')} &nbsp;&nbsp;千瓦时/元</div>
                                              </Card>
                                              <Unit> = </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（峰）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalPeakFee, 2, '-')} 元&nbsp;&nbsp;</div>
                                              </Card>
                                          </div>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Unit> （ </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度电量（平）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.flatAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {
                                                  data?.tenement?.feeType === 3 ? null : (
                                                      <>
                                                          <Unit> + </Unit>
                                                          <Card>
                                                              <h4 tw='mt-1 mb-1'> 线损电量（平）： </h4>
                                                              <div> {outputWithPrecision(data?.comprehensive?.lossFlat, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                                          </Card>
                                                      </>
                                                  )
                                              }

                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 公摊电量（平）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.poolFlat, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {/*<Unit> - </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 退补电量（平）： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.refundFlat, 2, '-')} &nbsp;&nbsp;千瓦时</div>*/}
                                              {/*</Card>*/}
                                              <Unit> ） </Unit><Unit> * </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 用电单价（平）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.priceFlat, 6, '-')} &nbsp;&nbsp;千瓦时/元</div>
                                              </Card>
                                              <Unit> = </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（平）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalFlatFee, 2, '-')} 元 &nbsp;&nbsp;</div>
                                              </Card>
                                          </div>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Unit> （ </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电度电量（谷）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.valleyAmount, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {
                                                  data?.tenement?.feeType === 3 ? null : (
                                                      <>
                                                          <Unit> + </Unit>
                                                          <Card>
                                                              <h4 tw='mt-1 mb-1'> 线损电量（谷）： </h4>
                                                              <div> {outputWithPrecision(data?.comprehensive?.lossValley, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                                          </Card>
                                                      </>
                                                  )
                                              }

                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 公摊电量（谷）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.poolValley, 2, '-')} &nbsp;&nbsp;千瓦时</div>
                                              </Card>
                                              {/*<Unit> - </Unit>*/}
                                              {/*<Card>*/}
                                              {/*    <h4 tw='mt-1 mb-1'> 退补电量（谷）： </h4>*/}
                                              {/*    <div> {outputWithPrecision(data?.comprehensive?.refundValley, 2, '-')} &nbsp;&nbsp;千瓦时</div>*/}
                                              {/*</Card>*/}
                                              <Unit> ） </Unit><Unit> * </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 用电单价（谷）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.priceValley, 6, '-')} &nbsp;&nbsp;千瓦时/元</div>
                                              </Card>
                                              <Unit> = </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（谷）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalValleyFee, 2, '-')} 元 &nbsp;&nbsp;</div>
                                              </Card>
                                          </div>
                                          <div tw='flex flex-row items-center flex-wrap'>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（尖）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalSharpFee, 2, '-')} 元
                                                  </div>
                                              </Card>
                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（峰）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalPeakFee, 2, '-')} 元
                                                  </div>
                                              </Card>
                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（平）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalFlatFee, 2, '-')} 元
                                                  </div>
                                              </Card>
                                              <Unit> + </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 电费（谷）： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.finalValleyFee, 2, '-')} 元
                                                  </div>
                                              </Card>
                                              <Unit> = </Unit>
                                              <Card>
                                                  <h4 tw='mt-1 mb-1'> 本期总电费： </h4>
                                                  <div> {outputWithPrecision(data?.comprehensive?.total, 2, '-')} 元 &nbsp;&nbsp;</div>
                                              </Card>
                                          </div>
                                          {/*<div tw='flex flex-row items-center' style={{height: '100%', flex: 1}}>*/}
                                          {/*    <Unit> = </Unit>*/}
                                          {/*    <Card style={{height: 200}}>*/}
                                          {/*        <h4 tw='mt-1 mb-1'> 本期总电费（元）： </h4>*/}
                                          {/*        <div> {outputWithPrecision(data?.comprehensive?.total, 2, '-')} </div>*/}
                                          {/*    </Card>*/}
                                          {/*</div>*/}
                                      </div>
                                  )
                              }
                          </div>
                          <div>
                              <div tw='mt-4'>
                                  用电明细
                                  <span style={{marginLeft: 20}}>
                                        （
                                        电度电量=（止码-起码）*倍率-退补电量-从表电量，
                                        合计电量=电度电量+线损电量+公摊电量
                                        ）
                                    </span>
                                  <Divider tw='mt-2 mb-4 flex flex-col w-full'/>
                              </div>
                              <div tw="mt-3" style={{fontSize: 12}}>
                                  <table border={1} width={"100%"} cellSpacing="0">
                                      <thead>
                                      <tr>
                                          <td>电表地址</td>
                                          <td>起码</td>
                                          <td>止码</td>
                                          <td>表倍率</td>
                                          <td>退补电量</td>
                                          <td>从表电量</td>
                                          <td>电度电量</td>
                                          {/* <td>线损占比</td> */}
                                          {
                                              data?.tenement?.feeType === 3 ? null : (
                                                  <td>线损电量</td>
                                              )
                                          }
                                          <td>公摊电量</td>
                                          <td>合计电量</td>
                                      </tr>
                                      </thead>
                                      <tbody>
                                      {renderTable()}
                                      {renderTableSum()}
                                      </tbody>
                                  </table>

                              </div>
                          </div>
                      </div>
                  </div>

              </ContentArea>
          </div>

      </>

  );
};
